@@ -1,6 +1,6 @@
 import logging
-from hein_control.automation.automation import Automation
-from hein_control.automation.step import CustomStep, ConditionCheck, IfStep
+from hein_control.automation import Automation
+from hein_control.step import CustomStep, ConditionCheck, IfStep
 
 class AA():
     def __init__(self):
